Lowercase

Struct Lowercase 

pub struct Lowercase<Mode> { /* private fields */ }
Rule and transformer for ensuring that a string is entirely lowercase.

Example

use wary::Wary;

#[derive(Wary)]
struct Person {
  #[validate(lowercase)]
  name: String,
  #[validate(lowercase(ascii))]
  greeting: String,
  #[transform(lowercase)]
  message: String,
}

let mut person = Person {
  name: "hello".into(),
  greeting: "hello".into(),
  message: "HELLO".into(),
};

assert!(person.wary(&()).is_ok());
assert_eq!(person.message, "hello");

Implementations

Source

impl Lowercase<Unset>

pub const fn new() -> Self

pub const fn ascii(self) -> Lowercase<Ascii>

Rule

Ensures that the input is entirely lowercase in ascii.

Transformer

Uses str::make_ascii_lowercase to convert in-place instead of requiring a new allocation with str::to_lowercase.